.. -*- coding: utf-8 -*-

.. _contents:

*************
Documentation
*************

==================
Cube bootstrap
================

Bootstrap-compatible components for CubicWeb.

This cube provides bootstrap version of views, components, boxes,
etc. but does not provide a main template.


.. toctree::
   :maxdepth: 1

   dependencies
   header
   primary

   release_0.6.0
   release_0.5.0
